You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@wookie.apache.org by sc...@apache.org on 2012/03/22 12:29:18 UTC

svn commit: r1303736 - in /incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework: Widget.java WidgetInstance.java

Author: scottbw
Date: Thu Mar 22 11:29:18 2012
New Revision: 1303736

URL: http://svn.apache.org/viewvc?rev=1303736&view=rev
Log:
Replaced methods deleted from 0.9.2 but added @deprecated tags to provide API-level backwards compatibility (see WOOKIE-330). 

Modified:
    incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/Widget.java
    incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/WidgetInstance.java

Modified: incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/Widget.java
URL: http://svn.apache.org/viewvc/incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/Widget.java?rev=1303736&r1=1303735&r2=1303736&view=diff
==============================================================================
--- incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/WidgetInstance.java (original)
+++ incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/WidgetInstance.java Thu Mar 22 11:29:18 2012
@@ -28,6 +28,24 @@ public class WidgetInstance {
   String height;
   String width;
 
+  /**
+   * @deprecated This constructor is for backwards compatibility only; new implementations should
+   * use the constructor with the ID Key parameter supplied
+   * @param url
+   * @param id
+   * @param title
+   * @param height
+   * @param width
+   */
+  public WidgetInstance(String url, String id, String title, String height,
+      String width) {
+    setId(id);
+    setUrl(url);
+    setTitle(title);
+    setHeight(height);
+    setWidth(width);
+  }
+  
   public WidgetInstance(String url, String id, String title, String height,
       String width, String idKey) {
     setId(id);
--- incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/Widget.java (original)
+++ incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/Widget.java Thu Mar 22 11:29:18 2012
@@ -60,12 +60,21 @@ public class Widget { 
   }
 
   /**
    * Get the human readable title of this widget.
    * @return
    */
   public String getName() {
     return name;
   }
+  
+  /**
+   * Get the human readable title of this widget.
+   * @deprecated Use "getName" instead
+   * @return the widget title
+   */
+  public String getTitle() {
+    return name;
+  }
 
   /**
    * Get the location of a logo for this widget.
@@ -60,12 +60,21 @@ public class Widget { 
 
   /**
-   * Get the human readable title of this widget.
-   * @return
+   * Get the human readable name of this widget.
+   * @return the widget name
    */
   public String getName() {

Modified: incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/WidgetInstance.java
URL: http://svn.apache.org/viewvc/incubator/wookie/trunk/connector/java/src/org/apache/wookie/connector/framework/WidgetInstance.java?rev=1303736&r1=1303735&r2=1303736&view=diff
==============================================================================